import { Plugin } from 'vite';
import { IncomingMessage } from 'http';
import { RequestHandler, Application } from 'express';

declare function multiDevice(rawOptions?: Record<string, unknown>): Plugin[];

declare type DevicesMap = Record<string, RegExp | boolean | ((req: IncomingMessage) => boolean)>;

declare type MultiDeviceConfig = {
    devices: string[] | DevicesMap;
    fallback: string;
    replacement: (device: string) => string | string[];
    resolvePath: (path: string, device: string) => string;
    env: 'DEVICE';
};
declare function loadConfig(): MultiDeviceConfig;
declare function getDevicesArray(config: Pick<MultiDeviceConfig, 'devices' | 'fallback'>): string[];

declare const deviceMiddleware: (devicesMap: DevicesMap, fallback: string) => RequestHandler;
declare function devMiddleware(root?: string | null): RequestHandler[];
declare function createDevServer(root?: null): Application;
declare function createProdServer(outputRaw?: string): Application;

export default multiDevice;
export { MultiDeviceConfig, createDevServer, createProdServer, devMiddleware, deviceMiddleware, getDevicesArray, loadConfig };
